;//////////////////////////////////////////////////////////////////////////////
;//
;//  Copyright (C) Microsoft Corporation.  All Rights Reserved.
;//
;//  File:       d3dx9tex.inc
;//  Content:    D3DX texturing APIs
;//
;//  Translated to .ASM by: Siekmanski
;//
;//////////////////////////////////////////////////////////////////////////////

ifndef __D3DX9TEX_H__
__D3DX9TEX_H__ equ 1

;//----------------------------------------------------------------------------
;// D3DX_FILTER flags:
;// ------------------
;//
;// A valid filter must contain one of these values:
;//
;//  D3DX_FILTER_NONE
;//      No scaling or filtering will take place.  Pixels outside the bounds
;//      of the source image are assumed to be transparent black.
;//  D3DX_FILTER_POINT
;//      Each destination pixel is computed by sampling the nearest pixel
;//      from the source image.
;//  D3DX_FILTER_LINEAR
;//      Each destination pixel is computed by linearly interpolating between
;//      the nearest pixels in the source image.  This filter works best 
;//      when the scale on each axis is less than 2.
;//  D3DX_FILTER_TRIANGLE
;//      Every pixel in the source image contributes equally to the
;//      destination image.  This is the slowest of all the filters.
;//  D3DX_FILTER_BOX
;//      Each pixel is computed by averaging a 2x2(x2) box pixels from 
;//      the source image. Only works when the dimensions of the 
;//      destination are half those of the source. (as with mip maps)
;//
;// And can be OR'd with any of these optional flags:
;//
;//  D3DX_FILTER_MIRROR_U
;//      Indicates that pixels off the edge of the texture on the U-axis
;//      should be mirrored, not wraped.
;//  D3DX_FILTER_MIRROR_V
;//      Indicates that pixels off the edge of the texture on the V-axis
;//      should be mirrored, not wraped.
;//  D3DX_FILTER_MIRROR_W
;//      Indicates that pixels off the edge of the texture on the W-axis
;//      should be mirrored, not wraped.
;//  D3DX_FILTER_MIRROR
;//      Same as specifying D3DX_FILTER_MIRROR_U | D3DX_FILTER_MIRROR_V |
;//      D3DX_FILTER_MIRROR_V
;//  D3DX_FILTER_DITHER
;//      Dithers the resulting image using a 4x4 order dither pattern.
;//  D3DX_FILTER_SRGB_IN
;//      Denotes that the input data is in sRGB (gamma 2.2) colorspace.
;//  D3DX_FILTER_SRGB_OUT
;//      Denotes that the output data is in sRGB (gamma 2.2) colorspace.
;//  D3DX_FILTER_SRGB
;//      Same as specifying D3DX_FILTER_SRGB_IN | D3DX_FILTER_SRGB_OUT
;//
;//----------------------------------------------------------------------------

D3DX_FILTER_NONE		equ (1 shl 0)
D3DX_FILTER_POINT		equ (2 shl 0)
D3DX_FILTER_LINEAR		equ (3 shl 0)
D3DX_FILTER_TRIANGLE		equ (4 shl 0)
D3DX_FILTER_BOX			equ (5 shl 0)

D3DX_FILTER_MIRROR_U		equ (1 shl 16)
D3DX_FILTER_MIRROR_V		equ (2 shl 16)
D3DX_FILTER_MIRROR_W		equ (4 shl 16)
D3DX_FILTER_MIRROR		equ (7 shl 16)

D3DX_FILTER_DITHER		equ (1 shl 19)
D3DX_FILTER_DITHER_DIFFUSION	equ (2 shl 19)

D3DX_FILTER_SRGB_IN		equ (1 shl 21)
D3DX_FILTER_SRGB_OUT		equ (2 shl 21)
D3DX_FILTER_SRGB		equ (3 shl 21)

;//----------------------------------------------------------------------------
;// D3DX_NORMALMAP flags:
;// ---------------------
;// These flags are used to control how D3DXComputeNormalMap generates normal
;// maps.  Any number of these flags may be OR'd together in any combination.
;//
;//  D3DX_NORMALMAP_MIRROR_U
;//      Indicates that pixels off the edge of the texture on the U-axis
;//      should be mirrored, not wraped.
;//  D3DX_NORMALMAP_MIRROR_V
;//      Indicates that pixels off the edge of the texture on the V-axis
;//      should be mirrored, not wraped.
;//  D3DX_NORMALMAP_MIRROR
;//      Same as specifying D3DX_NORMALMAP_MIRROR_U | D3DX_NORMALMAP_MIRROR_V
;//  D3DX_NORMALMAP_INVERTSIGN
;//      Inverts the direction of each normal 
;//  D3DX_NORMALMAP_COMPUTE_OCCLUSION
;//      Compute the per pixel Occlusion term and encodes it into the alpha.
;//      An Alpha of 1 means that the pixel is not obscured in anyway, and
;//      an alpha of 0 would mean that the pixel is completly obscured.
;//
;//----------------------------------------------------------------------------

;//----------------------------------------------------------------------------

D3DX_NORMALMAP_MIRROR_U		equ (1 shl 16)
D3DX_NORMALMAP_MIRROR_V		equ (2 shl 16)
D3DX_NORMALMAP_MIRROR		equ (3 shl 16)
D3DX_NORMALMAP_INVERTSIGN	equ (8 shl 16)
D3DX_NORMALMAP_COMPUTE_OCCLUSION equ (16 shl 16)

;//----------------------------------------------------------------------------
;// D3DX_CHANNEL flags:
;// -------------------
;// These flags are used by functions which operate on or more channels
;// in a texture.
;//
;// D3DX_CHANNEL_RED
;//     Indicates the red channel should be used
;// D3DX_CHANNEL_BLUE
;//     Indicates the blue channel should be used
;// D3DX_CHANNEL_GREEN
;//     Indicates the green channel should be used
;// D3DX_CHANNEL_ALPHA
;//     Indicates the alpha channel should be used
;// D3DX_CHANNEL_LUMINANCE
;//     Indicates the luminaces of the red green and blue channels should be 
;//     used.
;//
;//----------------------------------------------------------------------------

D3DX_CHANNEL_RED	equ (1 shl 0)
D3DX_CHANNEL_BLUE	equ (1 shl 1)
D3DX_CHANNEL_GREEN	equ (1 shl 2)
D3DX_CHANNEL_ALPHA	equ (1 shl 3)
D3DX_CHANNEL_LUMINANCE	equ (1 shl 4)

;//----------------------------------------------------------------------------
;// D3DXIMAGE_FILEFORMAT:
;// ---------------------
;// This enum is used to describe supported image file formats.
;//
;//----------------------------------------------------------------------------

D3DXIFF_BMP		equ 0
D3DXIFF_JPG		equ 1
D3DXIFF_TGA		equ 2
D3DXIFF_PNG		equ 3
D3DXIFF_DDS		equ 4
D3DXIFF_PPM		equ 5
D3DXIFF_DIB		equ 6
D3DXIFF_HDR		equ 7 ;//high dynamic range formats
D3DXIFF_PFM		equ 8
D3DXIFF_FORCE_DWORD	equ 07fffffffh

D3DXIMAGE_FILEFORMAT	typedef DWORD

;//----------------------------------------------------------------------------
;// LPD3DXFILL2D and LPD3DXFILL3D:
;// ------------------------------
;// Function types used by the texture fill functions.
;//
;// Parameters:
;//  pOut
;//      Pointer to a vector which the function uses to return its result.
;//      X,Y,Z,W will be mapped to R,G,B,A respectivly. 
;//  pTexCoord
;//      Pointer to a vector containing the coordinates of the texel currently 
;//      being evaluated.  Textures and VolumeTexture texcoord components 
;//      range from 0 to 1. CubeTexture texcoord component range from -1 to 1.
;//  pTexelSize
;//      Pointer to a vector containing the dimensions of the current texel.
;//  pData
;//      Pointer to user data.
;//
;//----------------------------------------------------------------------------

;typedef VOID (WINAPI *LPD3DXFILL2D)(D3DXVECTOR4 *pOut, 
;    CONST D3DXVECTOR2 *pTexCoord, CONST D3DXVECTOR2 *pTexelSize, LPVOID pData);

LPD3DXFILL2D	typedef PTR DWORD

;typedef VOID (WINAPI *LPD3DXFILL3D)(D3DXVECTOR4 *pOut, 
;    CONST D3DXVECTOR3 *pTexCoord, CONST D3DXVECTOR3 *pTexelSize, LPVOID pData);

LPD3DXFILL3D	typedef PTR DWORD
 
;//----------------------------------------------------------------------------
;// D3DXIMAGE_INFO:
;// ---------------
;// This structure is used to return a rough description of what the
;// the original contents of an image file looked like.
;// 
;//  Width
;//      Width of original image in pixels
;//  Height
;//      Height of original image in pixels
;//  Depth
;//      Depth of original image in pixels
;//  MipLevels
;//      Number of mip levels in original image
;//  Format
;//      D3D format which most closely describes the data in original image
;//  ResourceType
;//      D3DRESOURCETYPE representing the type of texture stored in the file.
;//      D3DRTYPE_TEXTURE, D3DRTYPE_VOLUMETEXTURE, or D3DRTYPE_CUBETEXTURE.
;//  ImageFileFormat
;//      D3DXIMAGE_FILEFORMAT representing the format of the image file.
;//
;//----------------------------------------------------------------------------
_D3DXIMAGE_INFO struct
	dx_Width	UINT ?
	dx_Height	UINT ?
	Depth		UINT ?
	MipLevels	UINT ?
	Format		D3DFORMAT ?
	ResourceType	D3DRESOURCETYPE ?
	ImageFileFormat	D3DXIMAGE_FILEFORMAT ?
_D3DXIMAGE_INFO ends

D3DXIMAGE_INFO	typedef _D3DXIMAGE_INFO

;//////////////////////////////////////////////////////////////////////////////
;// Image File APIs ///////////////////////////////////////////////////////////
;//////////////////////////////////////////////////////////////////////////////
;
;//----------------------------------------------------------------------------
;// GetImageInfoFromFile/Resource:
;// ------------------------------
;// Fills in a D3DXIMAGE_INFO struct with information about an image file.
;//
;// Parameters:
;//  pSrcFile
;//      File name of the source image.
;//  pSrcModule
;//      Module where resource is located, or NULL for module associated
;//      with image the os used to create the current process.
;//  pSrcResource
;//      Resource name
;//  pSrcData
;//      Pointer to file in memory.
;//  SrcDataSize
;//      Size in bytes of file in memory.
;//  pSrcInfo
;//      Pointer to a D3DXIMAGE_INFO structure to be filled in with the 
;//      description of the data in the source image file.
;//
;//----------------------------------------------------------------------------

D3DXGetImageInfoFromFileA	PROTO :DWORD,:DWORD
D3DXGetImageInfoFromFileW 	PROTO :DWORD,:DWORD

ifdef UNICODE
D3DXGetImageInfoFromFile	equ D3DXGetImageInfoFromFileW
else
D3DXGetImageInfoFromFile	equ D3DXGetImageInfoFromFileA
endif

D3DXGetImageInfoFromFileA	PROTO :DWORD,:DWORD
D3DXGetImageInfoFromFileW 	PROTO :DWORD,:DWORD

ifdef UNICODE
D3DXGetImageInfoFromFile	equ D3DXGetImageInfoFromFileW
else
D3DXGetImageInfoFromFile	equ D3DXGetImageInfoFromFileA
endif

D3DXGetImageInfoFromResourceA	PROTO :DWORD,:DWORD,:DWORD
D3DXGetImageInfoFromResourceW 	PROTO :DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXGetImageInfoFromResource	equ D3DXGetImageInfoFromResourceW
else
D3DXGetImageInfoFromResource	equ D3DXGetImageInfoFromResourceA
endif

D3DXGetImageInfoFromFileInMemory PROTO :DWORD,:DWORD,:DWORD

;//////////////////////////////////////////////////////////////////////////////
;// Load/Save Surface APIs ////////////////////////////////////////////////////
;//////////////////////////////////////////////////////////////////////////////

;//----------------------------------------------------------------------------
;// D3DXLoadSurfaceFromFile/Resource:
;// ---------------------------------
;// Load surface from a file or resource
;//
;// Parameters:
;//  pDestSurface
;//      Destination surface, which will receive the image.
;//  pDestPalette
;//      Destination palette of 256 colors, or NULL
;//  pDestRect
;//      Destination rectangle, or NULL for entire surface
;//  pSrcFile
;//      File name of the source image.
;//  pSrcModule
;//      Module where resource is located, or NULL for module associated
;//      with image the os used to create the current process.
;//  pSrcResource
;//      Resource name
;//  pSrcData
;//      Pointer to file in memory.
;//  SrcDataSize
;//      Size in bytes of file in memory.
;//  pSrcRect
;//      Source rectangle, or NULL for entire image
;//  Filter
;//      D3DX_FILTER flags controlling how the image is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
;//  ColorKey
;//      Color to replace with transparent black, or 0 to disable colorkey.
;//      This is always a 32-bit ARGB color, independent of the source image
;//      format.  Alpha is significant, and should usually be set to FF for 
;//      opaque colorkeys.  (ex. Opaque black == 0xff000000)
;//  pSrcInfo
;//      Pointer to a D3DXIMAGE_INFO structure to be filled in with the 
;//      description of the data in the source image file, or NULL.
;//
;//----------------------------------------------------------------------------

D3DXLoadSurfaceFromFileA	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXLoadSurfaceFromFileW	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXLoadSurfaceFromFile		equ D3DXLoadSurfaceFromFileW
else
D3DXLoadSurfaceFromFile		equ D3DXLoadSurfaceFromFileA
endif


D3DXLoadSurfaceFromResourceA	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXLoadSurfaceFromResourceW	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXLoadSurfaceFromResource	equ D3DXLoadSurfaceFromResourceW
else
D3DXLoadSurfaceFromResource	equ D3DXLoadSurfaceFromResourceA
endif

D3DXLoadSurfaceFromFileInMemory PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXLoadSurfaceFromSurface:
;// ---------------------------
;// Load surface from another surface (with color conversion)
;//
;// Parameters:
;//  pDestSurface
;//      Destination surface, which will receive the image.
;//  pDestPalette
;//      Destination palette of 256 colors, or NULL
;//  pDestRect
;//      Destination rectangle, or NULL for entire surface
;//  pSrcSurface
;//      Source surface
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  pSrcRect
;//      Source rectangle, or NULL for entire surface
;//  Filter
;//      D3DX_FILTER flags controlling how the image is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
;//  ColorKey
;//      Color to replace with transparent black, or 0 to disable colorkey.
;//      This is always a 32-bit ARGB color, independent of the source image
;//      format.  Alpha is significant, and should usually be set to FF for 
;//      opaque colorkeys.  (ex. Opaque black == 0xff000000)
;//
;//----------------------------------------------------------------------------

D3DXLoadSurfaceFromSurface	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXLoadSurfaceFromMemory:
;// --------------------------
;// Load surface from memory.
;//
;// Parameters:
;//  pDestSurface
;//      Destination surface, which will receive the image.
;//  pDestPalette
;//      Destination palette of 256 colors, or NULL
;//  pDestRect
;//      Destination rectangle, or NULL for entire surface
;//  pSrcMemory
;//      Pointer to the top-left corner of the source image in memory
;//  SrcFormat
;//      Pixel format of the source image.
;//  SrcPitch
;//      Pitch of source image, in bytes.  For DXT formats, this number
;//      should represent the width of one row of cells, in bytes.
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  pSrcRect
;//      Source rectangle.
;//  Filter
;//      D3DX_FILTER flags controlling how the image is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
;//  ColorKey
;//      Color to replace with transparent black, or 0 to disable colorkey.
;//      This is always a 32-bit ARGB color, independent of the source image
;//      format.  Alpha is significant, and should usually be set to FF for 
;//      opaque colorkeys.  (ex. Opaque black == 0xff000000)
;//
;//----------------------------------------------------------------------------

D3DXLoadSurfaceFromMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXSaveSurfaceToFile:
;// ----------------------
;// Save a surface to a image file.
;//
;// Parameters:
;//  pDestFile
;//      File name of the destination file
;//  DestFormat
;//      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
;//  pSrcSurface
;//      Source surface, containing the image to be saved
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  pSrcRect
;//      Source rectangle, or NULL for the entire image
;//
;//----------------------------------------------------------------------------

D3DXSaveSurfaceToFileA		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXSaveSurfaceToFileW		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXSaveSurfaceToFile		equ D3DXSaveSurfaceToFileW
else
D3DXSaveSurfaceToFile		equ D3DXSaveSurfaceToFileA
endif

;//----------------------------------------------------------------------------
;// D3DXSaveSurfaceToFileInMemory:
;// ----------------------
;// Save a surface to a image file.
;//
;// Parameters:
;//  ppDestBuf
;//      address of pointer to d3dxbuffer for returning data bits
;//  DestFormat
;//      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
;//  pSrcSurface
;//      Source surface, containing the image to be saved
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  pSrcRect
;//      Source rectangle, or NULL for the entire image
;//
;//----------------------------------------------------------------------------

D3DXSaveSurfaceToFileInMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//////////////////////////////////////////////////////////////////////////////
;// Load/Save Volume APIs /////////////////////////////////////////////////////
;//////////////////////////////////////////////////////////////////////////////

;//----------------------------------------------------------------------------
;// D3DXLoadVolumeFromFile/Resource:
;// --------------------------------
;// Load volume from a file or resource
;//
;// Parameters:
;//  pDestVolume
;//      Destination volume, which will receive the image.
;//  pDestPalette
;//      Destination palette of 256 colors, or NULL
;//  pDestBox
;//      Destination box, or NULL for entire volume
;//  pSrcFile
;//      File name of the source image.
;//  pSrcModule
;//      Module where resource is located, or NULL for module associated
;//      with image the os used to create the current process.
;//  pSrcResource
;//      Resource name
;//  pSrcData
;//      Pointer to file in memory.
;//  SrcDataSize
;//      Size in bytes of file in memory.
;//  pSrcBox
;//      Source box, or NULL for entire image
;//  Filter
;//      D3DX_FILTER flags controlling how the image is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
;//  ColorKey
;//      Color to replace with transparent black, or 0 to disable colorkey.
;//      This is always a 32-bit ARGB color, independent of the source image
;//      format.  Alpha is significant, and should usually be set to FF for 
;//      opaque colorkeys.  (ex. Opaque black == 0xff000000)
;//  pSrcInfo
;//      Pointer to a D3DXIMAGE_INFO structure to be filled in with the 
;//      description of the data in the source image file, or NULL.
;//
;//----------------------------------------------------------------------------

D3DXLoadVolumeFromFileA		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXLoadVolumeFromFileW		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXLoadVolumeFromFile		equ D3DXLoadVolumeFromFileW
else
D3DXLoadVolumeFromFile		equ D3DXLoadVolumeFromFileA
endif

D3DXLoadVolumeFromResourceA	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXLoadVolumeFromResourceW	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXLoadVolumeFromResource	equ D3DXLoadVolumeFromResourceW
else
D3DXLoadVolumeFromResource	equ D3DXLoadVolumeFromResourceA
endif

D3DXLoadVolumeFromFileInMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXLoadVolumeFromVolume:
;// -------------------------
;// Load volume from another volume (with color conversion)
;//
;// Parameters:
;//  pDestVolume
;//      Destination volume, which will receive the image.
;//  pDestPalette
;//      Destination palette of 256 colors, or NULL
;//  pDestBox
;//      Destination box, or NULL for entire volume
;//  pSrcVolume
;//      Source volume
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  pSrcBox
;//      Source box, or NULL for entire volume
;//  Filter
;//      D3DX_FILTER flags controlling how the image is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
;//  ColorKey
;//      Color to replace with transparent black, or 0 to disable colorkey.
;//      This is always a 32-bit ARGB color, independent of the source image
;//      format.  Alpha is significant, and should usually be set to FF for 
;//      opaque colorkeys.  (ex. Opaque black == 0xff000000)
;//
;//----------------------------------------------------------------------------

D3DXLoadVolumeFromVolume	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXLoadVolumeFromMemory:
;// -------------------------
;// Load volume from memory.
;//
;// Parameters:
;//  pDestVolume
;//      Destination volume, which will receive the image.
;//  pDestPalette
;//      Destination palette of 256 colors, or NULL
;//  pDestBox
;//      Destination box, or NULL for entire volume
;//  pSrcMemory
;//      Pointer to the top-left corner of the source volume in memory
;//  SrcFormat
;//      Pixel format of the source volume.
;//  SrcRowPitch
;//      Pitch of source image, in bytes.  For DXT formats, this number
;//      should represent the size of one row of cells, in bytes.
;//  SrcSlicePitch
;//      Pitch of source image, in bytes.  For DXT formats, this number
;//      should represent the size of one slice of cells, in bytes.
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  pSrcBox
;//      Source box.
;//  Filter
;//      D3DX_FILTER flags controlling how the image is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
;//  ColorKey
;//      Color to replace with transparent black, or 0 to disable colorkey.
;//      This is always a 32-bit ARGB color, independent of the source image
;//      format.  Alpha is significant, and should usually be set to FF for 
;//      opaque colorkeys.  (ex. Opaque black == 0xff000000)
;//
;//----------------------------------------------------------------------------

D3DXLoadVolumeFromMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXSaveVolumeToFile:
;// ---------------------
;// Save a volume to a image file.
;//
;// Parameters:
;//  pDestFile
;//      File name of the destination file
;//  DestFormat
;//      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
;//  pSrcVolume
;//      Source volume, containing the image to be saved
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  pSrcBox
;//      Source box, or NULL for the entire volume
;//
;//----------------------------------------------------------------------------

D3DXSaveVolumeToFileA		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXSaveVolumeToFileW		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXSaveVolumeToFile		equ D3DXSaveVolumeToFileW
else
D3DXSaveVolumeToFile		equ D3DXSaveVolumeToFileA
endif

;//----------------------------------------------------------------------------
;// D3DXSaveVolumeToFileInMemory:
;// ---------------------
;// Save a volume to a image file.
;//
;// Parameters:
;//  pDestFile
;//      File name of the destination file
;//  DestFormat
;//      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
;//  pSrcVolume
;//      Source volume, containing the image to be saved
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  pSrcBox
;//      Source box, or NULL for the entire volume
;//
;//----------------------------------------------------------------------------

D3DXSaveVolumeToFileInMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//////////////////////////////////////////////////////////////////////////////
;// Create/Save Texture APIs //////////////////////////////////////////////////
;//////////////////////////////////////////////////////////////////////////////

;//----------------------------------------------------------------------------
;// D3DXCheckTextureRequirements:
;// -----------------------------
;// Checks texture creation parameters.  If parameters are invalid, this
;// function returns corrected parameters.
;//
;// Parameters:
;//
;//  pDevice
;//      The D3D device to be used
;//  pWidth, pHeight, pDepth, pSize
;//      Desired size in pixels, or NULL.  Returns corrected size.
;//  pNumMipLevels
;//      Number of desired mipmap levels, or NULL.  Returns corrected number.
;//  Usage
;//      Texture usage flags
;//  pFormat
;//      Desired pixel format, or NULL.  Returns corrected format.
;//  Pool
;//      Memory pool to be used to create texture
;//
;//----------------------------------------------------------------------------

D3DXCheckTextureRequirements		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCheckCubeTextureRequirements	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCheckVolumeTextureRequirements	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXCreateTexture:
;// ------------------
;// Create an empty texture
;//
;// Parameters:
;//
;//  pDevice
;//      The D3D device with which the texture is going to be used.
;//  Width, Height, Depth, Size
;//      size in pixels. these must be non-zero
;//  MipLevels
;//      number of mip levels desired. if zero or D3DX_DEFAULT, a complete
;//      mipmap chain will be created.
;//  Usage
;//      Texture usage flags
;//  Format
;//      Pixel format.
;//  Pool
;//      Memory pool to be used to create texture
;//  ppTexture, ppCubeTexture, ppVolumeTexture
;//      The texture object that will be created
;//
;//----------------------------------------------------------------------------

D3DXCreateTexture		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateCubeTexture		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateVolumeTexture		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXCreateTextureFromFile/Resource:
;// -----------------------------------
;// Create a texture object from a file or resource.
;//
;// Parameters:
;//
;//  pDevice
;//      The D3D device with which the texture is going to be used.
;//  pSrcFile
;//      File name.
;//  hSrcModule
;//      Module handle. if NULL, current module will be used.
;//  pSrcResource
;//      Resource name in module
;//  pvSrcData
;//      Pointer to file in memory.
;//  SrcDataSize
;//      Size in bytes of file in memory.
;//  Width, Height, Depth, Size
;//      Size in pixels.  If zero or D3DX_DEFAULT, the size will be taken from 
;//      the file and rounded up to a power of two.  If D3DX_DEFAULT_NONPOW2, 
;//      the size will be not be rounded, if the device supports NONPOW2 textures.
;//  MipLevels
;//      Number of mip levels.  If zero or D3DX_DEFAULT, a complete mipmap
;//      chain will be created.
;//  Usage
;//      Texture usage flags
;//  Format
;//      Desired pixel format.  If D3DFMT_UNKNOWN, the format will be
;//      taken from the file.
;//  Pool
;//      Memory pool to be used to create texture
;//  Filter
;//      D3DX_FILTER flags controlling how the image is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
;//  MipFilter
;//      D3DX_FILTER flags controlling how each miplevel is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_BOX,
;//  ColorKey
;//      Color to replace with transparent black, or 0 to disable colorkey.
;//      This is always a 32-bit ARGB color, independent of the source image
;//      format.  Alpha is significant, and should usually be set to FF for 
;//      opaque colorkeys.  (ex. Opaque black == 0xff000000)
;//  pSrcInfo
;//      Pointer to a D3DXIMAGE_INFO structure to be filled in with the 
;//      description of the data in the source image file, or NULL.
;//  pPalette
;//      256 color palette to be filled in, or NULL
;//  ppTexture, ppCubeTexture, ppVolumeTexture
;//      The texture object that will be created
;//
;//----------------------------------------------------------------------------

;// FromFile
D3DXCreateTextureFromFileA	PROTO :DWORD,:DWORD,:DWORD
D3DXCreateTextureFromFileW	PROTO :DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateTextureFromFile	equ D3DXCreateTextureFromFileW
else
D3DXCreateTextureFromFile	equ D3DXCreateTextureFromFileA
endif

D3DXCreateCubeTextureFromFileA	PROTO :DWORD,:DWORD,:DWORD
D3DXCreateCubeTextureFromFileW	PROTO :DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateCubeTextureFromFile	equ D3DXCreateCubeTextureFromFileW
else
D3DXCreateCubeTextureFromFile	equ D3DXCreateCubeTextureFromFileA
endif

D3DXCreateVolumeTextureFromFileA PROTO :DWORD,:DWORD,:DWORD
D3DXCreateVolumeTextureFromFileW PROTO :DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateVolumeTextureFromFile	equ D3DXCreateVolumeTextureFromFileW
else
D3DXCreateVolumeTextureFromFile	equ D3DXCreateVolumeTextureFromFileA
endif

;// FromResource
D3DXCreateTextureFromResourceA	PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateTextureFromResourceW	PROTO :DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateTextureFromResource	equ D3DXCreateTextureFromResourceW
else
D3DXCreateTextureFromResource	equ D3DXCreateTextureFromResourceA
endif

D3DXCreateCubeTextureFromResourceA PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateCubeTextureFromResourceW PROTO :DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateCubeTextureFromResource equ D3DXCreateCubeTextureFromResourceW
else
D3DXCreateCubeTextureFromResource equ D3DXCreateCubeTextureFromResourceA
endif

D3DXCreateVolumeTextureFromResourceA PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateVolumeTextureFromResourceW PROTO :DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateVolumeTextureFromResource equ D3DXCreateVolumeTextureFromResourceW
else
D3DXCreateVolumeTextureFromResource equ D3DXCreateVolumeTextureFromResourceA
endif

;// FromFileEx
D3DXCreateTextureFromFileExA	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateTextureFromFileExW	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateTextureFromFileEx	equ D3DXCreateTextureFromFileExW
else
D3DXCreateTextureFromFileEx	equ D3DXCreateTextureFromFileExA
endif

D3DXCreateCubeTextureFromFileExA PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateCubeTextureFromFileExW PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateCubeTextureFromFileEx equ D3DXCreateCubeTextureFromFileExW
else
D3DXCreateCubeTextureFromFileEx equ D3DXCreateCubeTextureFromFileExA
endif

D3DXCreateVolumeTextureFromFileExA PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateVolumeTextureFromFileExW PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateVolumeTextureFromFileEx equ D3DXCreateVolumeTextureFromFileExW
else
D3DXCreateVolumeTextureFromFileEx equ D3DXCreateVolumeTextureFromFileExA
endif

;// FromResourceEx
D3DXCreateTextureFromResourceExA PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateTextureFromResourceExW PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateTextureFromResourceEx	equ D3DXCreateTextureFromResourceExW
else
D3DXCreateTextureFromResourceEx equ D3DXCreateTextureFromResourceExA
endif

D3DXCreateCubeTextureFromResourceExA PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateCubeTextureFromResourceExW PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateCubeTextureFromResourceEx equ D3DXCreateCubeTextureFromResourceExW
else
D3DXCreateCubeTextureFromResourceEx equ D3DXCreateCubeTextureFromResourceExA
endif

D3DXCreateVolumeTextureFromResourceExA PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateVolumeTextureFromResourceExW PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCreateVolumeTextureFromResourceEx equ D3DXCreateVolumeTextureFromResourceExW
else
D3DXCreateVolumeTextureFromResourceEx equ D3DXCreateVolumeTextureFromResourceExA
endif

;// FromFileInMemory
D3DXCreateTextureFromFileInMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateCubeTextureFromFileInMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateVolumeTextureFromFileInMemory PROTO :DWORD,:DWORD,:DWORD,:DWORD

;// FromFileInMemoryEx
D3DXCreateTextureFromFileInMemoryEx	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateCubeTextureFromFileInMemoryEx PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateVolumeTextureFromFileInMemoryEx PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXSaveTextureToFile:
;// ----------------------
;// Save a texture to a file.
;//
;// Parameters:
;//  pDestFile
;//      File name of the destination file
;//  DestFormat
;//      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
;//  pSrcTexture
;//      Source texture, containing the image to be saved
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//
;//----------------------------------------------------------------------------

D3DXSaveTextureToFileA		PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXSaveTextureToFileW		PROTO :DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXSaveTextureToFile		equ D3DXSaveTextureToFileW
else
D3DXSaveTextureToFile		equ D3DXSaveTextureToFileA
endif

;//----------------------------------------------------------------------------
;// D3DXSaveTextureToFileInMemory:
;// ----------------------
;// Save a texture to a file.
;//
;// Parameters:
;//  ppDestBuf
;//      address of a d3dxbuffer pointer to return the image data
;//  DestFormat
;//      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
;//  pSrcTexture
;//      Source texture, containing the image to be saved
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//
;//----------------------------------------------------------------------------

D3DXSaveTextureToFileInMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD

;//////////////////////////////////////////////////////////////////////////////
;// Misc Texture APIs /////////////////////////////////////////////////////////
;//////////////////////////////////////////////////////////////////////////////

;//----------------------------------------------------------------------------
;// D3DXFilterTexture:
;// ------------------
;// Filters mipmaps levels of a texture.
;//
;// Parameters:
;//  pBaseTexture
;//      The texture object to be filtered
;//  pPalette
;//      256 color palette to be used, or NULL for non-palettized formats
;//  SrcLevel
;//      The level whose image is used to generate the subsequent levels. 
;//  Filter
;//      D3DX_FILTER flags controlling how each miplevel is filtered.
;//      Or D3DX_DEFAULT for D3DX_FILTER_BOX,
;//
;//----------------------------------------------------------------------------

D3DXFilterTexture		PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXFilterCubeTexture		equ D3DXFilterTexture
D3DXFilterVolumeTexture		equ D3DXFilterTexture

;//----------------------------------------------------------------------------
;// D3DXFillTexture:
;// ----------------
;// Uses a user provided function to fill each texel of each mip level of a
;// given texture.
;//
;// Paramters:
;//  pTexture, pCubeTexture, pVolumeTexture
;//      Pointer to the texture to be filled.
;//  pFunction
;//      Pointer to user provided evalutor function which will be used to
;//  pData
;//      Pointer to an arbitrary block of user defined data.  This pointer 
;//      will be passed to the function provided in pFunction
;//-----------------------------------------------------------------------------

D3DXFillTexture			PROTO :DWORD,:DWORD,:DWORD
D3DXFillCubeTexture		PROTO :DWORD,:DWORD,:DWORD
D3DXFillVolumeTexture		PROTO :DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXFillTextureTX:
;// ----------------
;// Uses a TX Shader target to function to fill each texel of each mip level of a
;// given texture. The TX Shader target should be a compiled function taking 2
;// 2 paramters and returning a float4 color.
;//
;// Paramters:
;//  pTexture, pCubeTexture, pVolumeTexture
;//      Pointer to the texture to be filled.
;//  pFunction:
;//      Pointer to the compiled function returned by D3DX
;//  pConstants
;//      Constants used by program. Should be filled by user by parsing constant
;//      Table information
;//  Constants
;//      Number of Constants   
;//-----------------------------------------------------------------------------

D3DXFillTextureTX		PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXFillCubeTextureTX		PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXFillVolumeTextureTX		PROTO :DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXComputeNormalMap:
;// ---------------------
;// Converts a height map into a normal map.  The (x,y,z) components of each
;// normal are mapped to the (r,g,b) channels of the output texture.
;//
;// Parameters
;//  pTexture
;//      Pointer to the destination texture
;//  pSrcTexture
;//      Pointer to the source heightmap texture 
;//  pSrcPalette
;//      Source palette of 256 colors, or NULL
;//  Flags
;//      D3DX_NORMALMAP flags
;//  Channel
;//      D3DX_CHANNEL specifying source of height information
;//  Amplitude
;//      The constant value which the height information is multiplied by.
;//---------------------------------------------------------------------------

D3DXComputeNormalMap PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

endif ;//__D3DX9TEX_H__
